
Installation
============
To install the **latest release**, run::

    pip install cloup

Cloup adheres to `semantic versioning <https://semver.org/>`_.

.. important::
    As of v0.5, I don't expect to do introduce any major backward incompatibility.
    Nonetheless, since Cloup has not reached v1.0, its API is not to be
    considered stable. This doesn't mean you can't already safely use it:
    it is already tested and usable. Just make sure you pin the version you are
    using in your requirements, e.g.::

        cloup==0.5.*

    At each new release, I'll do my best to document what has changed in the
    :doc:`changelog`.

